searchData={"items":[{"type":"module","title":"Scribe","doc":"Pretty-print tables of structs and maps","ref":"Scribe.html"},{"type":"module","title":"Usage - Scribe","doc":"A common use case is printing results from an Ecto query.\n\n    # %User{id: nil, email: nil}\n\n    iex(1)> User |> limit(5) |> Repo.all() |> Scribe.print()\n    +-------------+----------------------------+------+\n    | :__struct__ | :email                     | :id  |\n    +-------------+----------------------------+------+\n    | User        | \"myles_fisher@beahan.com\"  | 5171 |\n    | User        | \"dawson_bartell@lynch.org\" | 4528 |\n    | User        | \"hassan1972@langworth.com\" | 1480 |\n    | User        | \"kiera.schulist@koch.com\"  | 2084 |\n    | User        | \"cynthia1970@mann.name\"    | 6599 |\n    +-------------+----------------------------+------+","ref":"Scribe.html#module-usage"},{"type":"module","title":"Pagination - Scribe","doc":"Scribe uses [pane](https://github.com/codedge-llc/pane) to paginate large tables.\nUse with `Scribe.console/2`.\n\n    # %User{id: nil, email: nil, first_name: nil, last_name: nil}\n    iex(1)> User |> limit(5) |> Repo.all |> Scribe.console\n\n    +-------------+------------------------+-------------+-------+------------+\n    | :__struct__ | :email                 | :first_name | :id   | :last_name |\n    +-------------+------------------------+-------------+-------+------------+\n    | User        | \"celestine_satterfield | \"Gene\"      | 9061  | \"Krajcik\"  |\n    | User        | \"lynn1978@bednar.org\"  | \"Maeve\"     | 9865  | \"Gerlach\"  |\n    | User        | \"melisa1975@hilll.biz\" | \"Theodora\"  | 2262  | \"Wunsch\"   |\n    | User        | \"furman.grady@ryan.org | \"Oswaldo\"   | 4977  | \"Simonis\"  |\n    | User        | \"caesar_hirthe@reynold | \"Arjun\"     | 3907  | \"Prohaska\" |\n    +-------------+------------------------+-------------+-------+------------+\n\n\n    [1 of 1] (j)next (k)prev (q)quit","ref":"Scribe.html#module-pagination"},{"type":"module","title":"Printing Custom Tables - Scribe","doc":"`Scribe.print/2` takes a list of of columns on the `:data` options key to\ncustomize output. You can use either the atom key or customize the header\nwith `{\"Custom Title\", :key}`.\n\n    # %User{id: nil, email: nil, first_name: nil, last_name: nil}\n\n    User\n    |> limit(5)\n    |> Repo.all\n    |> Scribe.print(data: [{\"ID\", :id}, :first_name, :last_name])\n\n    +------+--------------+-------------+\n    | \"ID\" | :first_name  | :last_name  |\n    +------+--------------+-------------+\n    | 9061 | \"Gene\"       | \"Krajcik\"   |\n    | 9865 | \"Maeve\"      | \"Gerlach\"   |\n    | 2262 | \"Theodora\"   | \"Wunsch\"    |\n    | 4977 | \"Oswaldo\"    | \"Simonis\"   |\n    | 3907 | \"Arjun\"      | \"Prohaska\"  |\n    +------+--------------+-------------+","ref":"Scribe.html#module-printing-custom-tables"},{"type":"module","title":"Function Columns - Scribe","doc":"You can specify functions that take the given row's struct or map as its only argument.\n\n    # %User{id: nil, email: nil, first_name: nil, last_name: nil}\n    results =\n      User\n      |> limit(5)\n      |> Repo.all\n      |> Scribe.print(data: [{\"ID\", :id}, {\"Full Name\", fn(x) -> \"#{x.last_name}, #{x.first_name}\" end}])\n\n    +--------------------------+----------------------------------------------+\n    | \"ID\"                     | \"Full Name\"                                  |\n    +--------------------------+----------------------------------------------+\n    | 9061                     | \"Krajcik, Gene\"                              |\n    | 9865                     | \"Gerlach, Maeve\"                             |\n    | 2262                     | \"Wunsch, Theodora\"                           |\n    | 4977                     | \"Simonis, Oswaldo\"                           |\n    | 3907                     | \"Prohaska, Arjun\"                            |\n    +--------------------------+----------------------------------------------+","ref":"Scribe.html#module-function-columns"},{"type":"module","title":"Styling Options - Scribe","doc":"","ref":"Scribe.html#module-styling-options"},{"type":"module","title":"Width - Scribe","doc":"Pass a `width` option to define table width.\n\n    iex> Scribe.print(data, width: 80)\n\n    +-------------------+-----------------------------------------------------+\n    | :id               | :key                                                |\n    +-------------------+-----------------------------------------------------+\n    | 910               | \"B1786AC67B4DEB19\"                                  |\n    | 313               | \"30CB8A2DE4750070\"                                  |\n    | 25                | \"D0859205FC7E7298\"                                  |\n    | 647               | \"8F0060AD0BD6AB04\"                                  |\n    | 253               | \"65509A684D619182\"                                  |\n    +-------------------+-----------------------------------------------------+","ref":"Scribe.html#module-width"},{"type":"module","title":"Disable Colors - Scribe","doc":"iex> Scribe.print(data, colorize: false)","ref":"Scribe.html#module-disable-colors"},{"type":"module","title":"Text Alignment - Scribe","doc":"Pass an `alignment` option of `:left`, `:center`, or `:right` for text alignment.\nDefaults to `:left`.\n\n    iex> Scribe.print(data, alignment: :center)\n\n    +------------------------------+------------+--------+\n    |            :body             |  :current  |  :id   |\n    +------------------------------+------------+--------+\n    |   \"A rather short string.\"   |    true    |  1234  |\n    |   \"A rather short string.\"   |   false    |  2222  |\n    |   \"A rather short string.\"   |    true    |  4444  |\n    +------------------------------+------------+--------+\n\n    iex> Scribe.print(data, alignment: :right)\n    +------------------------------+------------+--------+\n    |                        :body |   :current |    :id |\n    +------------------------------+------------+--------+\n    |     \"A rather short string.\" |       true |   1234 |\n    |     \"A rather short string.\" |      false |   2222 |\n    |     \"A rather short string.\" |       true |   4444 |\n    +------------------------------+------------+--------+","ref":"Scribe.html#module-text-alignment"},{"type":"module","title":"Styles - Scribe","doc":"Scribe supports five styling formats natively, with support for custom adapters.\nSee more in `Scribe.Style`.","ref":"Scribe.html#module-styles"},{"type":"function","title":"Scribe.console/2","doc":"Paginates data and starts a pseudo-interactive console.","ref":"Scribe.html#console/2"},{"type":"function","title":"Scribe.format/2","doc":"Formats data into a printable table string.","ref":"Scribe.html#format/2"},{"type":"function","title":"Examples - Scribe.format/2","doc":"iex> format([])\n    :ok\n\n    iex> format(%{test: 1234}, colorize: false)\n    \"+---------+\\n| :test   |\\n+---------+\\n| 1234    |\\n+---------+\\n\"","ref":"Scribe.html#format/2-examples"},{"type":"function","title":"Scribe.inspect/2","doc":"Prints a table from given data and returns the data.\n\nUseful for inspecting pipe chains.","ref":"Scribe.html#inspect/2"},{"type":"function","title":"Examples - Scribe.inspect/2","doc":"iex> Scribe.inspect([])\n    []\n\n    iex> Scribe.inspect(%{key: :value, test: 1234}, colorize: false)\n    +----------+---------+\n    | :key     | :test   |\n    +----------+---------+\n    | :value   | 1234    |\n    +----------+---------+\n    %{test: 1234, key: :value}","ref":"Scribe.html#inspect/2-examples"},{"type":"function","title":"Scribe.print/2","doc":"Prints a table from given data.","ref":"Scribe.html#print/2"},{"type":"function","title":"Examples - Scribe.print/2","doc":"iex> print([])\n    :ok\n\n    iex> Scribe.print(%{key: :value, test: 1234}, colorize: false)\n    +----------+---------+\n    | :key     | :test   |\n    +----------+---------+\n    | :value   | 1234    |\n    +----------+---------+\n    :ok","ref":"Scribe.html#print/2-examples"},{"type":"type","title":"Scribe.data/0","doc":"Printable data. Can be either a struct, map, or list of structs/maps.","ref":"Scribe.html#t:data/0"},{"type":"type","title":"Scribe.format_opts/0","doc":"Options for configuring table output.\n\n- `:alignment` - Define text alignment in cells. Defaults to `:left`.\n- `:colorize` - When `false`, disables colored output. Defaults to `true`\n- `:data` - Defines table headers\n- `:device` - Where to print (defaults to STDOUT)\n- `:style` - Style callback module. Defaults to `Scribe.Style.Default`\n- `:width` - Defines table width. Defaults to `:infinite`","ref":"Scribe.html#t:format_opts/0"},{"type":"module","title":"Scribe.Border","doc":"Defines border and edge symbols for a table cell.","ref":"Scribe.Border.html"},{"type":"module","title":"Example Usage - Scribe.Border","doc":"When printed, a cell with a border of `Scribe.Border.new(\"+\", \"|\", \"-\")`\nwould look like:\n\n```\n+--------+\n| \"test\" |\n+--------+\n```","ref":"Scribe.Border.html#module-example-usage"},{"type":"function","title":"Scribe.Border.new/3","doc":"Defines a new `Border.t` with given corner and edges.","ref":"Scribe.Border.html#new/3"},{"type":"function","title":"Examples - Scribe.Border.new/3","doc":"iex> new(\"+\", \"|\", \"-\")\n    %Scribe.Border{\n      top_left_corner: \"+\",\n      top_edge: \"-\",\n      top_right_corner: \"+\",\n      right_edge: \"|\",\n      bottom_right_corner: \"+\",\n      bottom_edge: \"-\",\n      bottom_left_corner: \"+\",\n      left_edge: \"|\"\n    }","ref":"Scribe.Border.html#new/3-examples"},{"type":"type","title":"Scribe.Border.t/0","doc":"","ref":"Scribe.Border.html#t:t/0"},{"type":"behaviour","title":"Scribe.Style","doc":"Defines styling callbacks for table printing.","ref":"Scribe.Style.html"},{"type":"behaviour","title":"Available Styles - Scribe.Style","doc":"- `Scribe.Style.Default`\n- `Scribe.Style.GithubMarkdown`\n- `Scribe.Style.NoBorder`\n- `Scribe.Style.Psql`\n- `Scribe.Style.Pseudo`","ref":"Scribe.Style.html#module-available-styles"},{"type":"callback","title":"Scribe.Style.border_at/4","doc":"","ref":"Scribe.Style.html#c:border_at/4"},{"type":"callback","title":"Scribe.Style.color/1","doc":"","ref":"Scribe.Style.html#c:color/1"},{"type":"function","title":"Scribe.Style.default/0","doc":"Returns default configured style.\n\nConfigure in your project:\n\n```\nconfig :scribe, style: Scribe.Style.Psql\n```\n\nDefaults to `Scribe.Style.Default` if not specified.","ref":"Scribe.Style.html#default/0"},{"type":"module","title":"Scribe.Style.Default","doc":"Default style.","ref":"Scribe.Style.Default.html"},{"type":"module","title":"Examples - Scribe.Style.Default","doc":"iex> Scribe.print(data, style: Scribe.Style.Default)\n\n    +-------+-----------------------------------+------------------------+\n    | :id   | :inserted_at                      | :key                   |\n    +-------+-----------------------------------+------------------------+\n    | 457   | \"2017-03-27 14:42:34.095202Z\"     | \"CEB0E055ECDF6028\"     |\n    | 326   | \"2017-03-27 14:42:34.097519Z\"     | \"CF67027F7235B88D\"     |\n    | 756   | \"2017-03-27 14:42:34.097553Z\"     | \"DE016DFF477BEDDB\"     |\n    | 484   | \"2017-03-27 14:42:34.097572Z\"     | \"9194A82EF4BB0123\"     |\n    | 780   | \"2017-03-27 14:42:34.097591Z\"     | \"BF92748B4AAAF14A\"     |\n    +-------+-----------------------------------+------------------------+","ref":"Scribe.Style.Default.html#module-examples"},{"type":"module","title":"Scribe.Style.GithubMarkdown","doc":"GitHub markdown style.","ref":"Scribe.Style.GithubMarkdown.html"},{"type":"module","title":"Examples - Scribe.Style.GithubMarkdown","doc":"iex> Scribe.print(data, style: Scribe.Style.GithubMarkdown)\n\n    | :id   | :inserted_at                      | :key                   |\n    |-------|-----------------------------------|------------------------|\n    | 457   | \"2017-03-27 14:42:34.095202Z\"     | \"CEB0E055ECDF6028\"     |\n    | 326   | \"2017-03-27 14:42:34.097519Z\"     | \"CF67027F7235B88D\"     |\n    | 756   | \"2017-03-27 14:42:34.097553Z\"     | \"DE016DFF477BEDDB\"     |\n    | 484   | \"2017-03-27 14:42:34.097572Z\"     | \"9194A82EF4BB0123\"     |\n    | 780   | \"2017-03-27 14:42:34.097591Z\"     | \"BF92748B4AAAF14A\"     |","ref":"Scribe.Style.GithubMarkdown.html#module-examples"},{"type":"module","title":"Scribe.Style.NoBorder","doc":"No-border style.","ref":"Scribe.Style.NoBorder.html"},{"type":"module","title":"Examples - Scribe.Style.NoBorder","doc":"iex> Scribe.print(data, style: Scribe.Style.NoBorder)\n\n     :id    :inserted_at                       :key\n     457    \"2017-03-27 14:42:34.095202Z\"      \"CEB0E055ECDF6028\"\n     326    \"2017-03-27 14:42:34.097519Z\"      \"CF67027F7235B88D\"\n     756    \"2017-03-27 14:42:34.097553Z\"      \"DE016DFF477BEDDB\"\n     484    \"2017-03-27 14:42:34.097572Z\"      \"9194A82EF4BB0123\"\n     780    \"2017-03-27 14:42:34.097591Z\"      \"BF92748B4AAAF14A\"","ref":"Scribe.Style.NoBorder.html#module-examples"},{"type":"module","title":"Scribe.Style.Pseudo","doc":"Pseudo style.","ref":"Scribe.Style.Pseudo.html"},{"type":"module","title":"Examples - Scribe.Style.Pseudo","doc":"iex> Scribe.print(data, style: Scribe.Style.Pseudo)\n\n    ┌───────┬───────────────────────────────────┬────────────────────────┐\n    │ :id   │ :inserted_at                      │ :key                   │\n    ├───────┼───────────────────────────────────┼────────────────────────┤\n    │ 457   │ \"2017-03-27 14:42:34.095202Z\"     │ \"CEB0E055ECDF6028\"     │\n    │ 326   │ \"2017-03-27 14:42:34.097519Z\"     │ \"CF67027F7235B88D\"     │\n    │ 756   │ \"2017-03-27 14:42:34.097553Z\"     │ \"DE016DFF477BEDDB\"     │\n    │ 484   │ \"2017-03-27 14:42:34.097572Z\"     │ \"9194A82EF4BB0123\"     │\n    │ 780   │ \"2017-03-27 14:42:34.097591Z\"     │ \"BF92748B4AAAF14A\"     │\n    └───────┴───────────────────────────────────┴────────────────────────┘","ref":"Scribe.Style.Pseudo.html#module-examples"},{"type":"module","title":"Scribe.Style.Psql","doc":"Psql style.","ref":"Scribe.Style.Psql.html"},{"type":"module","title":"Examples - Scribe.Style.Psql","doc":"iex> Scribe.print(data, style: Scribe.Style.Psql)\n\n     :id   | :inserted_at                      | :key\n    -------+-----------------------------------+------------------------\n     700   | \"2017-03-27 14:41:33.411442Z\"     | \"A2FA80D0F6DF9388\"\n     890   | \"2017-03-27 14:41:33.412955Z\"     | \"F95094328A91D950\"\n     684   | \"2017-03-27 14:41:33.412991Z\"     | \"1EAC6B28045ED644\"\n     531   | \"2017-03-27 14:41:33.413015Z\"     | \"DC2377B696355642\"\n     648   | \"2017-03-27 14:41:33.413037Z\"     | \"EA9311B4683A52B3\"","ref":"Scribe.Style.Psql.html#module-examples"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),\nand this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).","ref":"changelog.html"},{"type":"extras","title":"v0.11.0 - 2024-08-31 - Changelog","doc":"**Added**\n\n- Center and right text alignment options ([#16](https://github.com/codedge-llc/scribe/pull/16)).\n\n**Changed**\n\n- Bumped minimum Elixir version to 1.13.\n\n**Removed**\n\n- Removed `Scribe.auto_inspect/1`.\n- Removed `Scribe.auto_inspect?/0`.","ref":"changelog.html#v0-11-0-2024-08-31"},{"type":"extras","title":"v0.10.0 - 2019-05-29 - Changelog","doc":"- Added `:device` option to `Scribe.print/2` for printing to a specific device.\n  Defaults to `:stdio`","ref":"changelog.html#v0-10-0-2019-05-29"},{"type":"extras","title":"v0.9.0 - 2019-05-04 - Changelog","doc":"- `NoBorder` style added.","ref":"changelog.html#v0-9-0-2019-05-04"},{"type":"extras","title":"v0.8.2 - 2019-01-17 - Changelog","doc":"- Support for Elixir `v1.8`","ref":"changelog.html#v0-8-2-2019-01-17"},{"type":"extras","title":"v0.8.1 - 2018-07-25 - Changelog","doc":"- Support for Elixir `v1.7`","ref":"changelog.html#v0-8-1-2018-07-25"},{"type":"extras","title":"v0.8.0 - 2019-03-15 - Changelog","doc":"- `:compile_auto_inspect` and `:auto_inspect` config options, both default\n  to `false`.\n- Added `Scribe.auto_inspect/1` for toggling auto inspect.\n- Added `Scribe.auto_inspect?/0`.\n- Removed `Scribe.enable/0` and `Scribe.disable/0`, replaced with above.\n- Removed `Scribe.enabled?/0`, replaced with above.\n\nTo work with production releases, auto-inspect functionality can now be\noptionally compiled (not compiled by default). To enable auto-inspect for\nyour development environment, add this to your `config/dev.exs`:\n\n    config :scribe,\n      compile_auto_inspect: true,\n      auto_inspect: true\n\nTo temporarily disable auto-inspect in your shell, use\n`Scribe.auto_inspect(false)`. Inspect will work as normal until set to\ntrue again.\n\nIf auto-inspect is not compiled (or disabled), `Scribe.print/2` and similar\nfunctions will continue to work as normal.","ref":"changelog.html#v0-8-0-2019-03-15"},{"type":"extras","title":"v0.7.0 - 2018-02-19 - Changelog","doc":"- Pseudographics style added.","ref":"changelog.html#v0-7-0-2018-02-19"},{"type":"extras","title":"v0.6.0 - 2018-02-16 - Changelog","doc":"- Overrides Inspect protocol for `List` and `Map`. These types will now\n  automatically return in Scribe's table format. Disabled by default.\n  with `config :scribe, enable: false` in your Mix config.\n- `Scribe.enable`, `Scribe.disable`, and `Scribe.enabled?` added.\n- Minimum Elixir version bumped to `1.5`.","ref":"changelog.html#v0-6-0-2018-02-16"},{"type":"extras","title":"v0.5.1 - 2018-01-06 - Changelog","doc":"- Bump pane dependency to v0.2.0.","ref":"changelog.html#v0-5-1-2018-01-06"},{"type":"extras","title":"v0.5.0 - 2017-03-27 - Changelog","doc":"- `@behaviour Scribe.Style` implemented (See `/style` for example adapters)\n- Colorized output.\n- Default styling no longer separates data rows.\n- Tables no longer width-limited unless specified.","ref":"changelog.html#v0-5-0-2017-03-27"},{"type":"extras","title":"License","doc":"MIT License\n\nCopyright (c) 2016-2024 Codedge LLC (https://www.codedge.io/)\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}